@@ -2,6 +2,7 @@
 
 import click
 import pytest
+import sys
 
 from nile_coverage import logger
 from nile_coverage.plugins import PytestCairoCoveragePlugin
@@ -31,4 +32,4 @@ def coverage(mark, single_thread, contracts_folder, xml):
     if single_thread:
         args += ["-n", "0"]
 
-    pytest.main(args, plugins=[PytestCairoCoveragePlugin(contracts_folder, xml)])
+    sys.exit(pytest.main(args, plugins=[PytestCairoCoveragePlugin(contracts_folder, xml)]))
